==> activity-center-api-1.0.0-20160612.064711-7-sources.jar: cn/com/duiba/activity/center/api/dto/CategoryActivityDto.java <==
/**
 * Project Name:activity-center-api
 * File Name:CategoryActivityDto.java
 * Package Name:cn.com.duiba.activity.center.api.dto
 * Date:2016年6月8日下午4:04:25
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.api.dto;

/**
 * ClassName:CategoryActivityDto <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason:	 TODO ADD REASON. <br/>
 * Date:     2016年6月8日 下午4:04:25 <br/>
 * @author   duiba
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public class CategoryActivityDto {
    private Long id;
    private Long appId;
    private Long categoryId;
    private String titile;      //标题
    private String thumb;       //缩略图
    private String banner;      //banner图
    private Long credits;       //积分值
    private Integer payload;
    
    public Long getId() {
        return id;
    }
    
    public void setId(Long id) {
        this.id = id;
    }
    
    public Long getAppId() {
        return appId;
    }
    
    public void setAppId(Long appId) {
        this.appId = appId;
    }
    
    public Long getCategoryId() {
        return categoryId;
    }
    
    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    
    public String getTitile() {
        return titile;
    }
    
    public void setTitile(String titile) {
        this.titile = titile;
    }
    
    public String getThumb() {
        return thumb;
    }
    
    public void setThumb(String thumb) {
        this.thumb = thumb;
    }
    
    public String getBanner() {
        return banner;
    }
    
    public void setBanner(String banner) {
        this.banner = banner;
    }
    
    public Long getCredits() {
        return credits;
    }
    
    public void setCredits(Long credits) {
        this.credits = credits;
    }
    
    public Integer getPayload() {
        return payload;
    }
    
    public void setPayload(Integer payload) {
        this.payload = payload;
    }
    
    
}

==> activity-center-api-1.0.0-20160612.100424-10-sources.jar: cn/com/duiba/activity/center/api/dto/CategoryActivityDto.java <==
/**
 * Project Name:activity-center-api
 * File Name:CategoryActivityDto.java
 * Package Name:cn.com.duiba.activity.center.api.dto
 * Date:2016年6月8日下午4:04:25
 * Copyright (c) 2016, duiba.com.cn All Rights Reserved.
 *
*/

package cn.com.duiba.activity.center.api.dto;

/**
 * ClassName:CategoryActivityDto <br/>
 * Function: TODO ADD FUNCTION. <br/>
 * Reason:	 TODO ADD REASON. <br/>
 * Date:     2016年6月8日 下午4:04:25 <br/>
 * @author   duiba
 * @version  
 * @since    JDK 1.6
 * @see 	 
 */
public class CategoryActivityDto {
    private Long id;
    private Long appId;
    private Long categoryId;
    private String titile;      //标题
    private String thumb;       //缩略图
    private String banner;      //banner图
    private Long credits;       //积分值
    private Integer payload;
    private Long operatingId;
    
    public Long getId() {
        return id;
    }
    
    public void setId(Long id) {
        this.id = id;
    }
    
    public Long getAppId() {
        return appId;
    }
    
    public void setAppId(Long appId) {
        this.appId = appId;
    }
    
    public Long getCategoryId() {
        return categoryId;
    }
    
    public void setCategoryId(Long categoryId) {
        this.categoryId = categoryId;
    }
    
    public String getTitile() {
        return titile;
    }
    
    public void setTitile(String titile) {
        this.titile = titile;
    }
    
    public String getThumb() {
        return thumb;
    }
    
    public void setThumb(String thumb) {
        this.thumb = thumb;
    }
    
    public String getBanner() {
        return banner;
    }
    
    public void setBanner(String banner) {
        this.banner = banner;
    }
    
    public Long getCredits() {
        return credits;
    }
    
    public void setCredits(Long credits) {
        this.credits = credits;
    }
    
    public Integer getPayload() {
        return payload;
    }
    
    public void setPayload(Integer payload) {
        this.payload = payload;
    }

    
    public Long getOperatingId() {
        return operatingId;
    }
    
    public void setOperatingId(Long operatingId) {
        this.operatingId = operatingId;
    }
    
    
}
